@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -324,6 +324,25 @@ public class FormatData_lv extends ListResourceBundle {
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Laika josla: {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 t\u016bkstotis",
+                    "00 t\u016bkstotis",
+                    "000 t\u016bkstotis",
+                    "0 miljons",
+                    "00 miljons",
+                    "000 miljons",
+                    "0 miljards",
+                    "00 miljards",
+                    "000 miljards",
+                    "0 triljons",
+                    "00 triljons",
+                    "000 triljons",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -382,6 +401,25 @@ public class FormatData_lv extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0t\u016bkst'.'",
+                    "00\u00a0t\u016bkst'.'",
+                    "000\u00a0t\u016bkst'.'",
+                    "0\u00a0milj'.'",
+                    "00\u00a0milj'.'",
+                    "000\u00a0milj'.'",
+                    "0\u00a0mljrd'.'",
+                    "00\u00a0mljrd'.'",
+                    "000\u00a0mljrd'.'",
+                    "0\u00a0trilj'.'",
+                    "00\u00a0trilj'.'",
+                    "000\u00a0trilj'.'",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0}: vasaras laiks" },
             { "DatePatterns",
