@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -306,6 +306,25 @@ public class FormatData_uz_Cyrl extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat", "{0} \u0432\u0430\u049b\u0442\u0438" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u043c\u0438\u043d\u0433",
+                    "00 \u043c\u0438\u043d\u0433",
+                    "000 \u043c\u0438\u043d\u0433",
+                    "0 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "00 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "000 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "0 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
+                    "00 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
+                    "000 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
+                    "0 \u0442\u0440\u0438\u043b\u0438\u043e\u043d",
+                    "00 \u0442\u0440\u0438\u043b\u0438\u043e\u043d",
+                    "000 \u0442\u0440\u0438\u043b\u0438\u043e\u043d",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -343,6 +362,25 @@ public class FormatData_uz_Cyrl extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u043c\u0438\u043d\u0433",
+                    "00\u043c\u0438\u043d\u0433",
+                    "000\u043c\u0438\u043d\u0433",
+                    "0\u043c\u043b\u043d",
+                    "00\u043c\u043b\u043d",
+                    "000\u043c\u043b\u043d",
+                    "0\u043c\u043b\u0440\u0434",
+                    "00\u043c\u043b\u0440\u0434",
+                    "000\u043c\u043b\u0440\u0434",
+                    "0\u0442\u0440\u043b\u043d",
+                    "00\u0442\u0440\u043b\u043d",
+                    "000\u0442\u0440\u043b\u043d",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0} \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438" },
             { "DatePatterns",
